Name:           idfpml
Version:        20U1
Release:        1%{?dist}
Summary:        Intel Decimal Floating-Point Math Library
URL:            http://www.netlib.org/misc/intel/
License:        BSD
Group:          System Environment/Libraries
Source0:        http://www.netlib.org/misc/intel/IntelRDFPMathLib20U1.tar.gz
Patch1:         idfpml-20U1-sharedlib.patch
BuildRequires:  dos2unix

# Upstream does not provide support for ARM architecture.  Patching to treat
# armv7l as IA32 will get it to compile, but it fails the test suite.
# Need to file a bug in Red Hat Bugzilla, and block bug #485251.
ExcludeArch:    %{arm}

%description
Software implementation of the IEEE 754R Decimal Floating-Point
Arithmetic specification.  Ensures compliance with the upcoming
revision of the IEEE Standard for Floating-Point Arithmetic.  The
library implements the functions defined for decimal floating-point
arithmetic operations in the 'DRAFT Standard for Floating-Point
Arithmetic P754', which is a revision of the IEEE Standard 754-1985
for Binary Floating-Point Arithmetic.

# There are 16 different libraries built, which are the combinations of
# four binary build variables, CALL_BY_REF, GLOBAL_RND, GLOBAL_FLAGS,
# and UNCHANGED_BINARY_FLAGS.  The library name is
#    libbid<cbr><gr><gf><ubf>.so
# where <cbr>, <gr> and <gf> are "0" or "1" based on the first three build
# variables, and <ubf> is empty for UNCHANGED_BINARY_FLAGS == 0 and "b"
# for UNCHANGED_BINARY_FLAGS == 1

%package devel
Summary:        Development files for Intel Decimal Floating-Point Math Library
Group:          Development/Libraries
Requires:       idfpml = %{version}-%{release}

%description devel
Development files for the Intel Decimal Floating-Point Math Library.

%prep
%setup -q -n IntelRDFPMathLib%{version}

# Fix newlines and permissions
find . -type f -exec dos2unix -k {} \;
find . -type f -exec chmod a-x {} \;
chmod a+x LIBRARY/linuxbuild TESTS/linuxbuild

# Fedora-specific patch to build as a shared library. Upstream appears to be
# more concerned about portability and performance
%patch1 -p 1 -b .sharedlib

# Create pkgconfig files for all library variants
mkdir pkgconfig
cd pkgconfig
for ubf in 0 1
do
  if [ "$ubf" == "1" ]
  then
    ubfc="b"
  else
    ubfc=""
  fi
  for cbr in 0 1
  do
    for gr in 0 1
    do
      for gf in 0 1
      do
        cat <<EOF >idfpml$cbr$gr$gf$ubfc.pc
prefix=%{_prefix}
exec_prefix=%{_exec_prefix}
includedir=%{_includedir}
libdir=%{_libdir}

Name: idfpml$cbr$gr$gf$ubfc
Description: Intel Decimal Floating-Point Math Library
Version: %{version}
Cflags: -I$${includedir}/idfpml -DCALL_BY_REF=$cbr -DGLOBAL_RND=$gr -DGLOBAL_FLAGS=$gf -DUNCHANGED_BINARY_FLAGS=$ubf
Libs: -L$${libdir}/idfpml -lidfpml$cbr$gr$gf$ubfc
EOF
      done
    done
  done
done

%build
cd LIBRARY
# build system is inherently sequential, and doesn't work with SMP
CFLAGS_AUX="-fPIC %{optflags}" ./linuxbuild

%check
# On i686 but not x86_64, the test program will log some failures of the
# binary32_to_bid{32,64,128} functions to set the inexact status flag,
# but the numeric (or NaN) results are correct. The test code contains
# some mysterious code for a status "pollution_workaround", and doesn't
# abort when that occurs, so it's apparently not considered a major
# problem, and we'll ignore it.
cd TESTS
DEFINES="%{optflags} -I%{buildroot}%{_includedir}/idfpml -L%{buildroot}%{_libdir}/idfpml" LD_LIBRARY_PATH="%{buildroot}%{_libdir}/idfpml" ./linuxbuild

%install
install -d -m 755 %{buildroot}%{_libdir}/idfpml
cd LIBRARY
for f in libbid*.so
do
  install -m 755 $f %{buildroot}%{_libdir}/idfpml/$f.0.0
  ln -s $f.0.0 %{buildroot}%{_libdir}/idfpml/$f.0
  ln -s $f.0.0 %{buildroot}%{_libdir}/idfpml/$f
done
cd ..
install -d -m 755 %{buildroot}%{_includedir}/idfpml
install -m 644 LIBRARY/src/*.h %{buildroot}%{_includedir}/idfpml
install -d -m 755 %{buildroot}%{_libdir}/pkgconfig
install -m 644 pkgconfig/*.pc %{buildroot}%{_libdir}/pkgconfig

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%doc eula.txt README
%dir %{_libdir}/idfpml
%{_libdir}/idfpml/libbid*.so.*

%files devel
%doc LIBRARY/README
%doc EXAMPLES
%{_libdir}/idfpml/libbid*.so
%{_includedir}/idfpml
%{_libdir}/pkgconfig/*.pc

%changelog
* Sun May 18 2014 Eric Smith <brouhaha@fedoraproject.org> - 20U1-1
- initial version
